#ifndef CONSTANTS_H
#define CONSTANTS_H

#define SMALL_WIDTH 100
#define SMALL_HEIGH (SMALL_WIDTH * 5398 / 8660)

#define BIG_WIDTH 390
#define BIG_HEIGH (BIG_WIDTH * 5398 / 8660)

#define MAX_WIDTH 780
#define MAX_HEIGH (MAX_WIDTH * 5398 / 8660)

#define MAX_WIDTH_L 460
#define MAX_HEIGH_L (MAX_WIDTH_L * 5398 / 8660)

#define INTERNAL_WIDTH 400
#define INTERNAL_HEIGH (INTERNAL_WIDTH * 5398 / 8660)

#define KEY_SIZE 16

#define TEXT_ABOUT "<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
			"<br>"\
			"<p>if you think that qtWallet is useful for you, please</p>"\
			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>"


/*

Format 	Dimension 	Usage
ID-1 	85.60 × 53.98 mm 	Most banking cards and ID cards
ID-2 	105 × 74 mm 	German ID cards issued prior to Nov 2010
ID-3 	125 × 88 mm 	Passports and Visas

 */


#define TYPE_PASSWORD 6
#define TYPE_PHONE_NUMBER 5
#define TYPE_URL 4
#define TYPE_TEXT 3
#define TYPE_DATE 2
#define TYPE_STRING 0
#define TYPE_INTEGER 1


#endif
